Usage
calcPvalsMC(Tj, T0, digits, alternative = NULL, twosidedTstat = FALSE, p.conf.level=0.99)
calcPvals(Tj, T0, digits, denom = NULL, wgts = NULL, twosidedTstat = FALSE)
pCI(S, N, p.conf.level = 0.99)
Arguments
Tj
numeric vector of values of test statistic
T0
observed value of test statistic
digits
number of significant digits for rounding (see details)
alternative
character vector: one of "less", "greater", "two.sided"
twosidedTstat
logical, TRUE denotes test statistic is twosided
denom
total number of test statistics
wgts
vector of weights the same length as Tj, NULL gives all ones
S
number of Monte Carlo replications equal or more extreme than T0
N
number of Monte Carlo replications
p.conf.level
confidence level for confidence intervals about Monte Carlo p-values